# -*- coding: iso-8859-1 -*-
# pylint: disable-msg=E0201,C0103
# pylint-version = 0.7.0
#
# Copyright 2004-2005 Andr Malo or his licensors, as applicable
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Package svnmailer_test.unit

Testcases for ``svnmailer.__init__``

:var _tests: The test classes
:type _tests: ``list``
"""
__author__    = "Andr Malo"
__docformat__ = "restructuredtext en"
__all__       = ['getSuite']

from svnmailer_test import base
_tests = []


#### Test Bases                                     ####
########################################################
class TestBase(base.TestBase):
    """ Base class for browser tests """
    LOAD_MODULES = (('_init', 'svnmailer'),)


#### Test Cases                                     ####
########################################################
class _init_VersionTestCase(TestBase):
    """ svnmailer._Version """
    PREFIX = "_Version"

    def test00general(self):
        """ _Version is a private object """
        expected = object
        result = self._init._Version

        self.failUnless(issubclass(result, expected),
            "Is not an %r, but %r" % (expected, result))
        self.failIf(result.__name__ in self.public(self._init),
            "Is public")

    def test01init(self):
        """ .__init__ initializes the instance attributes """
        inst = self._init._Version(
            injected = "foo", version = "5.7.9", is_dev = False
        )
        self.mock.result = [
            inst.major, inst.minor, inst.patch, inst.is_dev, inst.string
        ]

        self.expect(5, 7, 9, False, '5.7.9')

    def test02init(self):
        """ .__init__ adds ``-dev`` to the version string """
        inst = self._init._Version(
            injected = "@@VERSION@@", version = "2.6.3", is_dev = True
        )
        self.mock.result = [
            inst.major, inst.minor, inst.patch, inst.is_dev, inst.string
        ]

        self.expect(2, 6, 3, True, '2.6.3-dev')

    def test03init(self):
        """ .__init__ passes the injected version string """
        inst = self._init._Version(
            injected = "injected", version = "8.5.3", is_dev = True
        )
        self.mock.result = [
            inst.major, inst.minor, inst.patch, inst.is_dev, inst.string
        ]

        self.expect(8, 5, 3, True, 'injected')

    def test04repr(self):
        """ .__repr__ returns a proper string """
        inst = self._init._Version(
            injected = "@@VERSION@@", version = "8.9.0", is_dev = True
        )
        self.mock.result.append(repr(inst))

        self.expect('<svnmailer.version 8.9.0-dev>')

_tests.append(_init_VersionTestCase)


class _init_mainTestCase(TestBase):
    """ svnmailer.__init__ """

    def test00main(self):
        """ __init__ provides as proper version """
        self.failUnless(isinstance(self._init.version, self._init._Version),
            "Is not a _Version")
        self.failUnless("version" in self.public(self._init),
            "Is not public")

_tests.append(_init_mainTestCase)


#### Glue code                                      ####
########################################################
__all__.extend(_tests)

def getSuite():
    """ Returns the test suite for this module """
    return [_test.__name__ for _test in _tests]
